Bootstrap网格 - Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

# Grid bootstrap grid sizing

.col-xs-12
.col-xs-1
.col-xs-11
.col-xs-6.col-sm-2
.col-xs-6.col-sm-10
.col-xs-12.col-lg-6
.col-xs-12.col-lg-6
.col-xs-4
.col-xs-8
.col-xs-5
.col-xs-7
.col-xs-6
.col-xs-6
.col-xs-7
.col-xs-5
.col-xs-8
.col-xs-4
.col-xs-9
.col-xs-3
.col-xs-10
.col-xs-2
.col-xs-11
.col-xs-1
.col-xs-12
Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container